@@ -8,6 +8,7 @@ months$months <- list()
 months$months[[1]] <- c(
   "january",
   "janvier",
+  "janeiro",
   "janv",
   "januar",
   "j\u00E4nner",
@@ -19,22 +20,42 @@ months$months[[2]] <- c(
   "february",
   "f\u00E9vrier",
   "fevrier",
+  "fevereiro",
   "f\u00E9vr",
   "fevr",
+  "fev",
   "februar",
   "febrero",
   "feb"
 )
-months$months[[3]] <- c("march", "mars", "m\u00E4rz", "marzo", "marz", "mar")
+months$months[[3]] <- c(
+  "march",
+  "mars",
+  "m\u00E4rz",
+  "marzo",
+  "mar\u00E7o",
+  "marco",
+  "marz",
+  "mar"
+)
 months$months[[4]] <- c("april", "avril", "abril", "abr", "apr")
-months$months[[5]] <- c("mayo", "may", "mai")
-months$months[[6]] <- c("june", "juin", "junio", "juni", "jun")
-months$months[[7]] <- c("july", "juillet", "juil", "julio", "juli", "jul")
+months$months[[5]] <- c("mayo", "may", "maio", "mai")
+months$months[[6]] <- c("june", "juin", "junio", "junho", "juni", "jun")
+months$months[[7]] <- c(
+  "july",
+  "juillet",
+  "juil",
+  "julio",
+  "julho",
+  "juli",
+  "jul"
+)
 months$months[[8]] <- c("august", "aug", "ao\u00FBt", "aout", "agosto")
 months$months[[9]] <- c(
   "september",
   "septembre",
   "septiembre",
+  "setembro",
   "set",
   "sept",
   "sep"
@@ -45,15 +66,18 @@ months$months[[10]] <- c(
   "oktober",
   "okt",
   "octubre",
-  "oct"
+  "outubro",
+  "oct",
+  "out"
 )
-months$months[[11]] <- c("november", "novembre", "noviembre", "nov")
+months$months[[11]] <- c("november", "novembre", "noviembre", "novembro", "nov")
 months$months[[12]] <- c(
   "december",
   "d\u00E9cembre",
   "decembre",
   "d\u00E9c",
   "dezember",
+  "dezembro",
   "dez",
   "diciembre",
   "dic",
